/*
 * Copyright 2018 Equilinox Mod Kit Project
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *    the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package equilinoxmodkit.util;


import equilinoxmodkit.mod.ModInfo;


/**
 * Utility class that provides methods to easily convert the version parameter within {@link ModInfo} to {@code int}s.
 *
 * @author EMK Team
 */
public final class VersionUtil {
	
	
	/** Private constructor because of statically used class. */
	private VersionUtil() {
	}
	
	
	/**
	 * Parses the {@link ModInfo#version()} parameter and returns it as an integer array in which index 0 corresponds to {@code MAJOR}, index 1 to
	 * {@code MINOR} and 2 to {@code PATCH} of the semantic versioning system.
	 *
	 * @param modInfo {@code ModInfo} to parse
	 *
	 * @return Specified {@code ModInfo} parsed to integer array.
	 */
	public static int[] getVersionArray( ModInfo modInfo ) {
		String[] tokens = modInfo.version().split( "\\." );
		int[] versions = new int[ tokens.length ];
		for( int i = 0;i < tokens.length;i++ ) {
			versions[ i ] = Integer.parseInt( tokens[ i ] );
		}
		return versions;
	}
	
	/**
	 * @param modInfo {@code ModInfo} to parse
	 *
	 * @return {@code MAJOR} parameter of the semantic versioning system.
	 */
	public static int getMajor( ModInfo modInfo ) {
		return Integer.parseInt( modInfo.version().split( "\\." )[ 0 ] );
	}
	
	/**
	 * @param modInfo {@code ModInfo} to parse
	 *
	 * @return {@code MINOR} of the semantic versioning system.
	 */
	public static int getMinor( ModInfo modInfo ) {
		return Integer.parseInt( modInfo.version().split( "\\." )[ 1 ] );
	}
	
	/**
	 * @param modInfo {@code ModInfo} to parse
	 *
	 * @return {@code PATCH} of the semantic versioning system.
	 */
	public static int getPatch( ModInfo modInfo ) {
		return Integer.parseInt( modInfo.version().split( "\\." )[ 2 ] );
	}
	
	
}
